@@ -1,5 +1,8 @@
 package Perinci::Sub::Property::result::table;
 
+our $DATE = '2015-01-07'; # DATE
+our $VERSION = '0.04'; # VERSION
+
 use 5.010001;
 use strict;
 use warnings;
@@ -9,8 +12,6 @@ use Locale::TextDomain::UTF8 'Perinci-Sub-Property-result-table';
 use Perinci::Object::Metadata;
 use Perinci::Sub::PropertyUtil qw(declare_property);
 
-our $VERSION = '0.03'; # VERSION
-
 declare_property(
     name => 'result/table',
     type => 'function',
@@ -80,8 +81,9 @@ declare_property(
             prio => 50,
         },
         handler => sub {
-            my ($self, %args) = @_;
-            my $table_spec = $self->{_help_meta}{result}{table}{spec}
+            my ($self, $r) = @_;
+            my $meta = $r->{_help_meta};
+            my $table_spec = $meta->{result}{table}{spec}
                 or return undef;
             my $text = __("Returns table data. Table fields are as follow:");
             $text .= "\n\n";
@@ -122,7 +124,7 @@ declare_property(
 
 
 1;
-#ABSTRACT: Specify table data in result
+# ABSTRACT: Specify table data in result
 
 __END__
 
@@ -136,7 +138,7 @@ Perinci::Sub::Property::result::table - Specify table data in result
 
 =head1 VERSION
 
-This document describes version 0.03 of Perinci::Sub::Property::result::table (from Perl distribution Perinci-Sub-Property-result-table), released on 2014-06-03.
+This document describes version 0.04 of Perinci::Sub::Property::result::table (from Perl distribution Perinci-Sub-Property-result-table), released on 2015-01-07.
 
 =head1 SYNOPSIS
 
@@ -318,7 +320,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Perinci-Su
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Perinci-Sub-Property-result_table>.
+Source repository is at L<https://github.com/perlancar/perl-Perinci-Sub-Property-result-table>.
 
 =head1 BUGS
 
@@ -330,11 +332,11 @@ feature.
 
 =head1 AUTHOR
 
-Steven Haryanto <stevenharyanto@gmail.com>
+perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Steven Haryanto.
+This software is copyright (c) 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
